@@ -1,4 +1,4 @@
-# Copyright (c) 2013, The MITRE Corporation. All rights reserved.
+# Copyright (c) 2014, The MITRE Corporation. All rights reserved.
 # See LICENSE.txt for complete terms.
 
 import cybox.bindings.whois_object as whois_binding
@@ -38,14 +38,15 @@ class WhoisContact(cybox.Entity):
     _binding_class = whois_binding.WhoisContactType
     _namespace = "http://cybox.mitre.org/objects#WhoisObject-2"
 
+    contact_type = TypedField("contact_type")
     contact_id = TypedField("Contact_ID", String)
-    contact_type = TypedField("Contact_Type", String)
     name = TypedField("Name", String)
     address = TypedField("Address", String)
     email_address = TypedField("Email_Address", EmailAddress)
     phone_number = TypedField("Phone_Number", String)
-
-
+    fax_number = TypedField("Fax_Number", String)
+    organization = TypedField("Organization", String)
+    
 class WhoisContacts(cybox.EntityList):
     _binding = whois_binding
     _binding_class = whois_binding.WhoisContactsType
@@ -93,12 +94,14 @@ class WhoisEntry(ObjectProperties):
     _XSI_NS = 'WhoisObj'
     _XSI_TYPE = 'WhoisObjectType'
 
+    lookup_date = TypedField("Lookup_Date", DateTime)
+    remarks = TypedField("Remarks", String)
     contact_info = TypedField("Contact_Info", WhoisContact)
     domain_name = TypedField("Domain_Name", URI)
     domain_id = TypedField("Domain_ID", String)
     server_name = TypedField("Server_Name", URI)
     ip_address = TypedField("IP_Address", Address)
-    dnssec = TypedField("DNSSEC", String)
+    dnssec = TypedField("DNSSEC")
     nameservers = TypedField("Nameservers", WhoisNameservers)
     status = TypedField("Status", WhoisStatuses)
     updated_date = TypedField("Updated_Date", Date)
